@@ -3,7 +3,7 @@
 from __future__ import absolute_import, unicode_literals
 
 __author__  = 'Jefurry <jefurry@qq.com>'
-__version__ = '0.1.2'
+__version__ = '0.1.3'
 
 import traceback
 from sqlbuilder import smartsql as sb
@@ -224,9 +224,10 @@ class Model(ModelBase):
         return self
 
     def __exit__(self, type, value, _traceback):
+        _debug = self._debug_
         del self
         if _traceback is not None:
-            if self._debug_:
+            if _debug:
                 self.logger.debug(traceback.format_exc())
             return False
         return True
